<?php

if (!$session->chkLevel(IS_ADMIN))
	throw new PleskUserException(lmsg('__perm_denied'));

$session->delParam(SPN_DOMAIN_ID);

$db_server_id = (int)get_gpc('db_server_id', 0);
if ($db_server_id <= 0)
	throw new PleskFatalException('Database server id is undefined');

require_once('DatabaseServerManager.php');
$serverManager = DatabaseServerManager::getInstance();
$server = $serverManager->getServer($db_server_id);

if ($server->getAttr('host') == 'localhost')
	$displayName = lmsg('__local_server_' . $server->getAttr('type'));
else
	$displayName = $server->getAttr('host') . ':' . $server->getAttr('port');

$listCommand = '';

$cmd = get_gpc('cmd');
$dbWebAdminURL = false;
switch ($cmd)
{
case 'remove':
	$del = get_gpc('del');
	if (is_array($del) && sizeof($del)) {
		$dbManager = $serverManager->getDatabaseManager($server);
		if (get_gpc('removeConfirmed')) {
			try {
				foreach ($del as $item) {
					$dbManager->deleteDatabase(objectMaker('Database', (int)$item));
				}
			} catch (PleskUserDBException $e) {
				$message = lmsg('database_server_error__real__' . $e->getCategory());
				if ($e->getCategory() != 'credentials_not_set')
					$message .= "\n\n" . $e->getMessage();
				error($message);
				break;
			}
		} else {
			require_once('class.RemoveForm.php');

			$list = '<ul>';
			foreach ($del as $item) {
				$id = (int)$item;
				$list .=  "<input type='hidden' name='del[]' value='$id'>";
				$database = objectMaker('Database', (int)$item);
				$list .= '<li>';
				$list .= safetyhtml($database->getAttr('name'));
				$users = $dbManager->fetchDatabaseUsers($database);
				if ($users) {
					$list .= '<ul>';
					foreach ($users as $user)
						$list .= "<li>$user[login]</li>";
					$list .= '</ul><br>';
				}
				$list .= '</li>';
			}
			$list .= '</ul>';
			$vars = array(
				'ACTION'			=> safetyhtml("$PHP_SELF?db_server_id=$db_server_id"),
				'PAGE_TITLE' 		=> lmsg('database_server_databases_form__remove_title'),
				'UPDATE_BUTTON'		=> RemoveForm::getUpdateButton(null, 'confirm_submit(); return false'),
				'TEXT_AGREEMENT'	=> lmsg('__confirm_removal'),
				'LIST'				=> $list,
			);

			$myRemoveForm = new RemoveForm($vars);
			$myRemoveForm->FastPrint();
			exit();
		}
	} else
		error(lmsg('database_server_databases_form__remove_empty_selection'));
	break;

case 'dbwebadmin':

	try {
		$dbManager = $serverManager->getDatabaseManager($server);
		if (!$serverManager->isTypeAllowedByKey($server->getAttr('type'))) {
			error(lmsg('__database_type_not_supported_by_key'));
			$dbWebAdminURL = false;
			break;
		}

		$conn_exception = $dbManager->testConnection();
		if (!$conn_exception) {
			$dbManager->setWebAdminParams();
			$dbWebAdminURL = $dbManager->getWebAdminURL();
		} else {
			error($conn_exception->getMessage());
			$dbWebAdminURL = false;
		}
		setcookie('phpMyAdmin', '', time() - 3600, '/');
	} catch (PleskUserDBException $e) {
		$dbWebAdminURL = false;
		error($e->getMessage());
	}

	break;

default:
	$listCommand = $cmd;
	break;
}

require_once('DatabaseServerDatabasesForm.php');
$form = new DatabaseServerDatabasesForm;
$form->define();
$form->assign($server, $listCommand, $dbWebAdminURL);
$form->parse();
$form->FastPrint();
?>
